%%
%% CLASS FILE FOR PROCEDINGS OF MSJ ANNUAL/AUTUMN MEETINGS
%%
%% Copyright (C) 2009- Mathematical Society Japan
%%
%%    web: http://mathsoc.jp/meeting/texstyle/
%% e-mail: texstyle@mathsoc.jp

%% [HISTORY]
%% 2022/06/15  v2.0.1  Added required versions for LaTeX, l3keys2e and expl3
%%                     Fixed a bug for \thanks
%%                     Fixed a bug in theorem environment
%% 2022/05/23  v2.0.0  support uplatex, lualatex
%%                     deleted options kikaku, sougou, 10pt, 11pt
%%                     deleted commands \lecturetype
%%                     and more changes...
%% 2011/10/31  v1.0.1  ignore \enlargethispage
%% 2011/10/27  v1.0.0  new page layout
%% 2010/02/09  v0.9.7  bugfix of '_' in math-mode
%% 2009/12/19  v0.9.6  support \tableofcontents
%%                     modify theorem style in Japanese mode
%% 2009/12/18  v0.9.5  support \email, \webpage commands
%% 2009/12/17  v0.9.4  support \date, \address commands, 
%%                     AMS like abstract environment
%% 2009/12/16  v0.9.3  support 'kikaku' option
%% 2009/12/15  v0.9.2  support bibtex/jbibtex, support 'kikaku' format
%% 2009/11/24  v0.9.1  typeset article head with 12pt mode
%% 2009/11/20  v0.9
%% 2009/09/14  v0.1  

% It works (maybe) TeX Live >= 2017

\NeedsTeXFormat{LaTeX2e}[2017/04/15]
\ProvidesClass{msjproc}[2022/06/15]
\def\msjprocversion{2.0.1}
\typeout{## Class file for Proceedings of MSJ Annual/Autumn Meetings}
\typeout{## MSJPROC.CLS version \msjprocversion}
\typeout{## Copyright (C) 2009- Mathematical Society Japan}

\RequirePackage{l3keys2e}[2018/02/21]
\RequirePackage{expl3}[2018/02/21]
\ExplSyntaxOn

% ꎞϐ
\tl_new:N \l__msjproc_tmpa_tl
\tl_new:N \l__msjproc_tmpb_tl
\tl_new:N \l__msjproc_tmpc_tl
\str_new:N \l__msjproc_tmpa_str
\int_new:N \l__msjproc_tmpa_int
\seq_new:N \l__msjproc_tmpa_seq

% Optioni[pϐ
\str_new:N \g__msjproc_engine_str
\bool_new:N \g__msjproc_english_bool
\str_new:N \g__msjproc_dvidriver_str
\bool_new:N \g__msjproc_draft_bool
\str_gset:Nn \g__msjproc_engine_str {}
\bool_gset_false:N \g__msjproc_english_bool
\bool_gset_false:N \g__msjproc_draft_bool

\keys_define:nn { msjproc } {
  platex .code:n = { \str_gset:Nn \g__msjproc_engine_str { platex } },
  uplatex .code:n = { \str_gset:Nn \g__msjproc_engine_str { uplatex } },
  lualatex .code:n = { \str_gset:Nn \g__msjproc_engine_str { lualatex } },
  pdflatex .code:n = { \str_gset:Nn \g__msjproc_engine_str { pdflatex } },
  xelatex .code:n = { \str_gset:Nn \g__msjproc_engine_str { xelatex } },
  english .bool_gset:N = \g__msjproc_english_bool,
  draft .bool_gset:N = \g__msjproc_draft_bool,
  dvipdfmx .code:n = { \str_gset:Nn \g__msjproc_dvidriver_str { dvipdfmx } },
  dvips .code:n = { \str_gset:Nn \g__msjproc_dvidriver_str { dvips } },
  pdftex .code:n = { \str_gset:Nn \g__msjproc_dvidriver_str { pdftex } },
  luatex .code:n = { \str_gset:Nn \g__msjproc_dvidriver_str { luatex } },
  xetex .code:n = { \str_gset:Nn \g__msjproc_dvidriver_str { xetex } },
  % disabled options
  twocolumn .code:n = { \OptionNotUsed },
  tombow .code:n = { \OptionNotUsed },
  tombo .code:n = { \OptionNotUsed },
  mentuke .code:n = { \OptionNotUsed },
}
\ProcessKeysOptions { msjproc }
% GW
\RequirePackage{ifptex,ifluatex,ifxetex,iftex}
\ifuptex
  \str_gset:Nn \l__msjproc_tmpa_str { uplatex }
  \else\ifptex
    \str_gset:Nn \l__msjproc_tmpa_str { platex }
    \else\ifluatex
      \str_gset:Nn \l__msjproc_tmpa_str { lualatex }
      \else\ifxetex
        \str_gset:Nn \l__msjproc_tmpa_str { xelatex }
        \else\ifPDFTeX
          \str_gset:Nn \l__msjproc_tmpa_str { pdflatex }
        \fi
      \fi
    \fi
  \fi
\fi

% IvVɃGW^ĂȂΓ肵GWgD
% ^Ăꍇ͐I`FbND
\str_if_eq:VnTF \g__msjproc_engine_str { } {
  \str_if_eq:VnT \l__msjproc_tmpa_str { } {
    \ClassError { msjproc } { msjproc~failed~to~guess~the~engine } { \@ehc }
  }
  \str_set_eq:NN \g__msjproc_engine_str \l__msjproc_tmpa_str
  \message { msjproc~guessed~engine:~\g__msjproc_engine_str }
}{
  \str_if_eq:VnF \l__msjproc_tmpa_str { } {
    \str_if_eq:NNF \g__msjproc_engine_str \l__msjproc_tmpa_str {
      \ClassError { msjproc } { You~are~running~\l__msjproc_tmpa_str,~but~the~option~`\g__msjproc_engine_str'~is~given.~Please~use~the~correct~option~or~delete~the~option~`\g__msjproc_engine_str' } {\@ehc}
    }
  }
}

% pdflatex, xelatex͓{̓T|[gȂD
\bool_if:NF \g__msjproc_english_bool {
  \bool_if:nT { ( \str_if_eq_p:Vn \g__msjproc_engine_str { pdflatex } ) || ( \str_if_eq_p:Vn \g__msjproc_engine_str { xelatex } ) }{
    \ClassError { msjproc } { Japanese~article~is~not~supported~with~the~engine~\g__msjproc_engine_str.~please~add~the~option~`english'~if~you~are~writing~English~article~or~please~use~another~engine~(platex,~uplatex~or~lualatex)~to~write~Japanese~article } { \@ehc }
  }
}

\bool_if:nT { \str_if_eq_p:Vn \g__msjproc_engine_str { platex } || \str_if_eq_p:Vn \g__msjproc_engine_str { uplatex } } {
  \epTeXinputencoding "utf8"
}

%. NXt@C̓ǂݍ
\bool_if:NTF \g__msjproc_draft_bool {
  \tl_set:Nn \l__msjproc_tmpa_tl { draft, }
}{
  \tl_set:Nn \l__msjproc_tmpa_tl { }
}
\bool_if:NTF \g__msjproc_english_bool {
  \LoadClass[
    \l__msjproc_tmpa_tl
    a4paper,12pt,twoside,onecolumn
  ]{article}
}{
  \exp_args:No \str_case:nn { \g__msjproc_engine_str } {
    { platex } { \LoadClass[\l__msjproc_tmpa_tl 12pt,nomag,twoside,onecolumn]{jsarticle} \def\zw{zw} \def\zh{zh} }
    { uplatex } { \LoadClass[\l__msjproc_tmpa_tl 12pt,nomag,uplatex,twoside,onecolumn]{jsarticle} \def\zw{zw} \def\zh{zh} }
    { lualatex } { \LoadClass[\l__msjproc_tmpa_tl 12pt,twoside,onecolumn]{ltjsarticle} }
  }
}
\bool_if:nTF {
  \str_if_eq_p:Vn \g__msjproc_dvidriver_str { dvipdfmx } ||
  (
    \str_if_eq_p:Vn \g__msjproc_dvidriver_str { } && 
    ( \str_if_eq_p:Vn \g__msjproc_engine_str { platex } || \str_if_eq_p:Vn \g__msjproc_engine_str { uplatex } )
  )
}{
  \tl_set:Nn \l__msjproc_tmpa_tl { dvipdfm, }
}{
  \tl_set:Nn \l__msjproc_tmpa_tl { }
}
\RequirePackage[\l__msjproc_tmpa_tl paper=a4paper,vmargin=25mm,hmargin=27.5mm,onecolumn]{geometry}
\RequirePackage{amsmath,amssymb,amsthm,url}

\dim_new:N \g__msjproc_titlesep_dim
\dim_gset:Nn \g__msjproc_titlesep_dim { 12pt }

% Ŗʗpp[^ύXĂȂ̃`FbN
\tl_new:N \g__msjproc_checkpagesizecode_tl
\clist_map_inline:nn {textwidth,textheight,headsep,headheight,topmargin,evensidemargin,oddsidemargin}{
  \tl_put_right:Nx \g__msjproc_checkpagesizecode_tl {
    \exp_not:N \dim_compare:nF { \exp_not:n { \dim_use:c {#1} } = \dim_use:c { #1 } } {
      \exp_not:n { \ClassError { msjproc } { Do~not~change~\expandafter\string\csname #1 \endcsname } {\@ehc} }
    }
  }
}
\AtEndDocument{\g__msjproc_checkpagesizecode_tl}

%. Ҋ֌W̃}N
\int_new:N \g__msjproc_authorcnt_int
\int_set:Nn \g__msjproc_authorcnt_int {0}
% ɒҏauthor-<Ԗڂ>̂悤ɂēD
\prop_new:N \g__msjproc_authorinfo_prop
\def\author#1#2{
  \int_gincr:N \g__msjproc_authorcnt_int
  \exp_args:NNx \prop_gput:Nnx \g__msjproc_authorinfo_prop { author-\int_use:N \g__msjproc_authorcnt_int } { \exp_not:n {#1} }
  \exp_args:NNx \prop_gput:Nnx \g__msjproc_authorinfo_prop { affil-\int_use:N \g__msjproc_authorcnt_int } { \exp_not:n {#2} }
}
\def\address#1{
  \exp_args:NNx \prop_gput:Nnx \g__msjproc_authorinfo_prop { address-\int_use:N \g__msjproc_authorcnt_int } { \exp_not:n {#1} }
}
\def\email#1{
  \exp_args:NNx \prop_gput:Nnx \g__msjproc_authorinfo_prop { email-\int_use:N \g__msjproc_authorcnt_int } { \exp_not:n {#1} }
}
\def\webpage#1{
  \exp_args:NNx \prop_gput:Nnx \g__msjproc_authorinfo_prop { webpage-\int_use:N \g__msjproc_authorcnt_int } { \exp_not:n {#1} }
}
\tl_new:N \g__msjproc_authorfootnote_tl
\def\authorfootnote#1{
  \footnotemark
  \tl_gput_right:Nx \g__msjproc_authorfootnote_tl {
    \exp_not:N \footnotetext[\the\c@footnote]{ \exp_not:n {#1} }
  }
}
\cs_set:Nn \__msjproc_authorslist: {{
  \let\footnote\authorfootnote
  \int_compare:nNnTF { \int_use:N \g__msjproc_authorcnt_int } = {1} {
    \def\thefootnote{\@fnsymbol\c@footnote}%
  }{
    \def\thefootnote{\@fnasternum\c@footnote}%
  }
  \int_set:Nn \l__msjproc_tmpa_int { \the\value{footnote} }
  \setcounter{footnote}{0}
  % \l__msjproc_tmpa_tlɒ҃Xgi[
  \tl_set:Nn \l__msjproc_tmpa_tl {}
  \int_step_inline:nnnn {1} {1} {\int_use:N \g__msjproc_authorcnt_int } {
    \int_compare:nNnT {##1}>{1} { \tl_put_right:Nn \l__msjproc_tmpa_tl {\\} }
    % \l__msjproc_tmpb_tlɋrɏo
    \tl_set:Nn \l__msjproc_tmpb_tl {}
    \tl_put_right:Nx \l__msjproc_tmpb_tl { \prop_item:Nn \g__msjproc_authorinfo_prop { address-##1 } }
    \prop_if_in:NnT \g__msjproc_authorinfo_prop { email-##1 } {
      \tl_if_empty:NF \l__msjproc_tmpb_tl { \tl_put_right:Nn \l__msjproc_tmpb_tl { \\ } }
      \tl_put_right:Nx \l__msjproc_tmpb_tl { e-mail:~\exp_not:N \protect \exp_not:N \url{ \prop_item:Nn \g__msjproc_authorinfo_prop { email-##1 } } }
    }
    \prop_if_in:NnT \g__msjproc_authorinfo_prop { webpage-##1 } {
      \tl_if_empty:NF \l__msjproc_tmpb_tl { \tl_put_right:Nn \l__msjproc_tmpb_tl { \\ } }
      \tl_put_right:Nx \l__msjproc_tmpb_tl { web:~\exp_not:N \protect \exp_not:N \url{ \prop_item:Nn \g__msjproc_authorinfo_prop { webpage-##1 } } }
    }
    \tl_set:Nx \l__msjproc_tmpc_tl { \prop_item:Nn \g__msjproc_authorinfo_prop { affil-##1 } }
    \tl_if_empty:NTF \l__msjproc_tmpc_tl {
      \tl_put_right:Nx \l__msjproc_tmpa_tl { \exp_not:N \multicolumn{3}{l}{\prop_item:Nn \g__msjproc_authorinfo_prop { author-##1 } } }
    }{
      \tl_put_right:Nx \l__msjproc_tmpa_tl { \prop_item:Nn \g__msjproc_authorinfo_prop { author-##1 } \exp_not:N &\exp_not:N \hbox to 1em{\exp_not:N \hss}\exp_not:N &(\prop_item:Nn \g__msjproc_authorinfo_prop { affil-##1 })}
    }
    \tl_if_empty:NF \l__msjproc_tmpb_tl {
      \tl_put_right:Nx \l__msjproc_tmpa_tl { \exp_not:N \footnote { \exp_not:o \l__msjproc_tmpb_tl } }
    }
  }
  \setlength\tabcolsep{0pt}
  \begin{tabular}{lll}
  \l__msjproc_tmpa_tl
  \end{tabular}%
  \g__msjproc_authorfootnote_tl
  \tl_clear:N \g__msjproc_authorfootnote_tl
  \setcounter{footnote}{ \int_use:N \l__msjproc_tmpa_int }
}}

%. KEYWOARDS / AMS SUBJECT CLASSIFICATION
\bool_if:NTF \g__msjproc_english_bool {
%  \newcommand\keywordsname{\char\jis"252D\char\jis"213C\char\jis"256F%
%    \char\jis"213C\char\jis"2549\char\jis"2127}%
  \newcommand{\keywordsname}{Keywords:\ }%
  \newcommand{\@msj@punct}{.}%
}{
  \newcommand{\keywordsname}{L[[hF}
  \newcommand{\@msj@punct}{}%
}
\tl_new:N \g__msjproc_keywords_tl
\newcommand*{\keywords}[1]{
  \tl_gset:Nn \g__msjproc_keywords_tl { \keywordsname#1\@msj@punct }
  \ignorespaces
}
\tl_new:N \g__msjproc_subjclass_tl
\newcommand*{\subjclass}[2][2020]{%
  \bool_if:nT { \int_compare_p:n { #1 != 1991 } && \int_compare_p:n { #1 != 2000 } && \int_compare_p:n { #1 != 2010 } && \int_compare_p:n { #1 != 2020 } } {
    \ClassError{msjproc}{Unknown~edition~(#1)~of~Mathematics~Subject~Classification}
  }
  \tl_gset:Nn \g__msjproc_subjclass_tl {
    #1~Mathematics~Subject~Classification:~#2\@msj@punct
  }
}


%. FOOTNOTE
\renewcommand{\@makefnmark}{\@textsuperscript{\normalfont\@thefnmark}}
\renewcommand{\@makefntext}[1]{%
  \leftskip=1.1em
  \parindent=0em
  \noindent
  \hbox to 0pt{\hss\@makefnmark\kern0.1em}#1
}
\newcommand{\@fnasternum}[1]{\ensuremath{*}\the#1}
\newcommand{\@fnasters}[1]{\ensuremath{\ifcase#1\or 
  {*}\or {*}{*}\or {*}{*}{*}\or {*}{*}{*}{*}\or 
  {*}\the#1\fi}}


%. DATE / THANKS
\let\@date\@empty
\tl_new:N \g__msjproc_thanks_tl
\renewcommand{\thanks}[1]{ \tl_gset:Nn \g__msjproc_thanks_tl {#1} }

\bool_if:NTF \g__msjproc_english_bool {
  \newcommand{\msjprocheadfont}{\bfseries\sffamily}
}{
  \newcommand{\msjprocheadfont}{\bfseries\sffamily\gtfamily}
}


% .section etc
%\def\@seccntformat#1{\csname the#1\endcsname.\ }
\RequirePackage{titlesec}
\dim_new:N \g__msjproc_section_after_label_space_dim
\bool_if:NTF \g__msjproc_english_bool {
  \dim_gset:Nn \g__msjproc_section_after_label_space_dim { 1em }
}{
  \dim_gset:Nn \g__msjproc_section_after_label_space_dim { 1\zw }
}
\titleformat{\section}{\large\msjprocheadfont}{\thesection}{\g__msjproc_section_after_label_space_dim}{}
\titlespacing{\section}{0pt}{.5\baselineskip}{.5\baselineskip}
\titleformat{\subsection}{\msjprocheadfont}{\thesubsection}{\g__msjproc_section_after_label_space_dim}{}
\titlespacing{\subsection}{0pt}{.5\baselineskip}{0pt}
\titleformat{\subsubsection}{\msjprocheadfont}{\thesubsubsection}{\g__msjproc_section_after_label_space_dim}{}
\titlespacing{\subsubsection}{0pt}{0pt}{0pt}
\titleformat{\paragraph}[runin]{}{}{}{}
\titlespacing{\paragraph}{0pt}{0pt}{0pt}
\titleformat{\subparagraph}[runin]{}{}{}{}
\titlespacing{\subparagraph}{\parindent}{0pt}{0pt}

%. \maketitle
\tl_new:N \g__msjproc_subtitle_tl
\def\subtitle#1 { \tl_gset:Nn \g__msjproc_subtitle_tl {#1} }

% \maketitleォ̃XCb`
\bool_new:N \g__msjproc_aftermaketitle_bool
\bool_set_false:N \g__msjproc_aftermaketitle_bool
\renewcommand{\maketitle}{\par
  \bool_set_true:N \g__msjproc_aftermaketitle_bool
  \begingroup
    \newpage
    \global\@topnum\z@
    \@maketitle
  \endgroup
  \ifvoid\msjproc@abstractbox\else\unvbox\msjproc@abstractbox\fi
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \tl_gclear:N \g__msjproc_thanks_tl
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

\def\@maketitle{%
  \let\mmsjproc@footnote@orig\footnote
  \let\footnote\titlefootnote
  \setlength{\parskip}{\g__msjproc_titlesep_dim}
  \setlength\topsep{0pt}%
  \setlength\partopsep{0pt}%
  \begin{center}
    \begin{minipage}[c]{135mm}%
      \centering
      \Large
      \setlength\baselineskip{21pt}%
      \setlength\lineskiplimit{4pt}%
      \setlength\lineskip{4pt}%
      \setlength\parskip{3pt}%
      \setlength\parsep{0pt}%
      \@title
      \tl_if_empty:NF \g__msjproc_subtitle_tl {
        \par
        \vskip0.5\g__msjproc_titlesep_dim
        \large
        \setlength\baselineskip{16pt}%
        \setlength\lineskiplimit{2pt}%
        \setlength\lineskip{2pt}%
        \g__msjproc_subtitle_tl
      }
    \end{minipage}
    \par
    %%%% list of authors
    \__msjproc_authorslist:
    \par
    \let\footnote\mmsjproc@footnote@orig
    %%%% date
    \ifx\@date\@empty\else\@date\fi
  \end{center}%
  \vspace{\g__msjproc_titlesep_dim}%
  %%%% title information
  \__msjproc_titleinfo:
}

\tl_new:N \g__msjproc_titlefootnote_tl
\def\titlefootnote#1{
  \footnotemark
  \tl_gput_right:Nx \g__msjproc_titlefootnote_tl {
    \exp_not:N \footnotetext[\the\c@footnote]{ \exp_not:n {#1} }
  }
}

\cs_set:Nn \__msjproc_titleinfo: {{
  \def\@makefntext##1{\leftskip=0em \parindent=0em \noindent##1}
  \let\@makefnmark\relax
  \let\@thefnmark\relax
  \tl_if_empty:NF \g__msjproc_thanks_tl { \@footnotetext { \g__msjproc_thanks_tl } }
  \tl_if_empty:NF \g__msjproc_subjclass_tl { \@footnotetext { \g__msjproc_subjclass_tl } }
  \tl_if_empty:NF \g__msjproc_keywords_tl { \@footnotetext { \g__msjproc_keywords_tl } }
}}


%. abstract
\bool_if:NTF \g__msjproc_english_bool {
  \renewcommand{\abstractname}{Abstract}
}{
  \renewcommand{\abstractname}{T\hspace{2\zw}v}%
%    \char\jis"3335\hspace{2zw}\char\jis"4D57}
}
\newbox\msjproc@abstractbox
\renewenvironment{abstract}{
  \let\footnote\abstractfootnote
  % S{bNXɓ
  \global\setbox\msjproc@abstractbox=\vbox\bgroup
    \begin{center}
    \small
    \setlength\topsep{0pt}%
    \setlength\parskip{0pt}%
    \setlength\partopsep{0pt}%
    \list{}{%
      \setlength\listparindent{\parindent}%
      \setlength\itemindent{0pt}%
      \setlength\leftmargin{15mm}%
      \setlength\rightmargin{15mm}%
      \setlength\topsep{0pt}%
      \setlength\partopsep{0pt}%
      \setlength\parsep{0.5ex}%
      \setlength\parskip{0pt}
    }%
    \setlength\parindent{0pt}%
    \item\relax
    \begin{center}%
      \textbf{\abstractname}%
    \end{center}%
    \par\ignorespaces
}{
    \endlist
    \hrule height 0pt depth 0pt
    \g__msjproc_abstractfootnote_tl
    \tl_clear:N \g__msjproc_abstractfootnote_tl
    \end{center}
    \vspace{\g__msjproc_titlesep_dim}
  \egroup
  % \maketitlěȂ΂̏ŏóD
  \bool_if:NT \g__msjproc_aftermaketitle_bool {
    \unvbox\msjproc@abstractbox
  }
}
\tl_new:N \g__msjproc_abstractfootnote_tl
\def\abstractfootnote#1{
  \footnotemark
  \tl_gput_right:Nx \g__msjproc_abstractfootnote_tl {
    \exp_not:N \footnotetext[\the\c@footnote]{ \exp_not:n {#1} }
  }
}

%. tableofcontents
\RequirePackage{titletoc}
\setcounter{tocdepth}{3}
\renewcommand{\tableofcontents}{
  \bgroup
  \list{}{%
    \setlength\topsep{\g__msjproc_titlesep_dim}
    \setlength\leftmargin{15mm}%
    \setlength\rightmargin{15mm}
  }
    \item
    \topsep=0pt 
    \begin{center}
      \small
      \textbf{\contentsname}%
    \end{center}
    \parskip=0pt\relax
    \@starttoc{toc}
  \endlist
  \egroup
}
% l͂ƓKcc
\contentsmargin{0mm}
\titlecontents{section}
  [0pt]
  {}
  {\hspace{2.9em}\contentslabel{2.9em}}{}
  {\titlerule*{.}\thecontentspage}
\titlecontents{subsection}
  [0.7em]
  {}
  {\hspace{2.2em}\contentslabel{2.2em}}{}
  {\titlerule*{.}\thecontentspage}
\titlecontents{subsubsection}
  [2.4em]
  {}
  {\hspace{3.3em}\contentslabel{3.3em}}{}
  {\titlerule*{.}\thecontentspage}
\titlecontents{paragraph}
  [6.8em]
  {}
  {}{}
  {\titlerule*{.}\thecontentspage}
\titlecontents{subparagraph}
  [7.8em]
  {}
  {}{}
  {\titlerule*{.}\thecontentspage}


\bool_if:NTF \g__msjproc_english_bool {
  \renewcommand{\contentsname}{Contents}
}{
  \renewcommand{\contentsname}{\hspace{2\zw}}
%    \char\jis"4C5C\hspace{2zw}\char\jis"3C21}
}
\pagestyle{empty}

%. bibliography
\def\@openbib@code{%
  \smallskip
  \small
  \setlength\itemsep{0.5ex}%
  \setlength\parsep{0pt}%
  \setlength\parskip{0ex}}

%. DISABLED COMMANDS
\clist_map_inline:nn {\enlargethispage}{
  \def#1{
    \ClassError { msjproc } { \noexpand#1is~disabled~in~this~class~file } {\@ehc}
  }
}

%. y[WX^C̖
\let\ps@plain=\@undefined
\let\ps@headings=\@undefined
\let\ps@myheadings=\@undefined

%. theorem environment for Japanese style
\bool_if:NF \g__msjproc_english_bool {
  \newtheoremstyle{msjproc}{.5\baselineskip}{.5\baselineskip}{}{0pt}{\msjprocheadfont}{}{1\zw}{\thmname{#1}\thmnumber{\ #2}\thmnote{i#3j}}
  \tl_set:Nx \l__msjproc_tmpa_tl {
    \exp_not:n { \cs_set:Npn \__msjproc_proof: [#1] } {
      \exp_not:n { \labelsep=1\zw }
      \exp_not:o { \proof[{\msjprocheadfont #1\inhibitglue}\nopunct] }%
    }
  }
  \l__msjproc_tmpa_tl
  \def\proof{\@ifnextchar[{\__msjproc_proof:}{\__msjproc_proof:[\proofname]}}
  \renewcommand{\proofname}{ؖ}
  \theoremstyle{msjproc}
}

\ExplSyntaxOff
\endinput
